import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

// Data set URI
const csvUrl = 'https://gist.githubusercontent.com/curran/a08a1080b88344b0c8a7/raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/iris.csv';  

// Format the Data from the URI response
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;

// Appends a SVG in the body of HTML
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  
  // Creating a new Scatter Plot object
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 39,
      right: 20,
      bottom:80,
      left: 90
    })
    .radius(5);

  // Plotting the Scatter Plot axes based on the given parameters
  svg.call(plot);

  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
  // Plotting the data on the Scatter Plot
  let i = 0;
 	setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.select(".x.label").remove()
  	svg.append("text")
        .attr("class", "x label")
        .attr("text-anchor", "end")
        .attr("x", width-400)
        .attr("y", height-10)
        .attr("fill", "Blue")
        .attr("font-size", "24px")
        .attr("font-family", "Arial, Helvetica, sans-serif")
        .text(columns[i % columns.length]);
    svg.call(plot);
    i++;
  }, 2000);
  svg.append("text")
        .attr("class", "x label")
        .attr("text-anchor", "end")
        .attr("x", width-400)
        .attr("y", height-10)
        .attr("fill", "Blue")
        .attr("font-size", "24px")
        .attr("font-family", "Arial, Helvetica, sans-serif")
        .text("Petal_Width");

      svg.append("text")
      .attr("class", "y label")
      .attr("text-anchor", "end")
      .attr("y", 10)
      .attr("dy", ".65em")
      .attr("dx", "-5.65em")
      .attr("transform", "rotate(-90)")
    	.attr("fill", "Blue")
    	.attr("font-size", "24px")
  		.attr("font-family", "Arial, Helvetica, sans-serif")
      .text("Sepal Length");
};
main();



